OC.L10N.register(
    "tasks",
    {
    "Tasks" : "משימות",
    "Due yesterday" : "נועד להתקיים אתמול",
    "Due today" : "נועד להתקיים היום",
    "Due tomorrow" : "נועד להתקיים מחר",
    "Due on" : "נועד להתקיים ב־",
    "Started yesterday" : "התחיל אתמול",
    "Starts today" : "מתחיל היום",
    "Starts tomorrow" : "מתחיל מחר",
    "Started on" : "התחיל ב־",
    "Starts on" : "מתחיל ב־",
    "[Remind me yesterday at ]HH:mm" : "[התזכורת הופעלה אתמול בשעה ]HH:mm",
    "[Remind me today at ]HH:mm" : "[התזכורת מופעלת היום בשעה ]HH:mm",
    "[Remind me tomorrow at ]HH:mm" : "[התזכורת תופעל מחר בשעה ]HH:mm",
    "[Remind me on ]MMM DD, YYYY,[ at ]HH:mm" : "[הפעלת תזכורת לתאריך ]MMM DD, YYYY,[ בשעה ]HH:mm",
    "Yesterday" : "אתמול",
    "Today" : "היום",
    "Tomorrow" : "מחר",
    "in %s" : "ב־%s",
    "%s ago" : "לפני %s",
    "seconds" : "שניות",
    "a minute" : "דקה",
    "%d minutes" : "%d דקות",
    "an hour" : "שעה",
    "%d hours" : "%d שעות",
    "a day" : "יום",
    "%d days" : "%d ימים",
    "a month" : "חודש",
    "%d months" : "%d חודשים",
    "a year" : "שנה",
    "%d years" : "%d שנים",
    "week" : "שבוע",
    "weeks" : "שבועות",
    "day" : "יום",
    "days" : "ימים",
    "hour" : "שעה",
    "hours" : "שעות",
    "minute" : "דקה",
    "minutes" : "דקות",
    "second" : "שניה",
    "before beginning" : "לפני התחלה",
    "after beginning" : "אחרי התחלה",
    "before end" : "לפני סיום",
    "after end" : "אחרי סיום",
    "Comment" : "תגובה",
    "Add a comment" : "הוספת תגובה",
    "This will delete the Calendar \"%s\" and all of its entries." : "פעולה זו תמחק את היומן \"%s\" ואת כל הרשומות בו.",
    "The name \"%s\" is already used." : "השם \"%s\" כבר קיים.",
    "An empty name is not allowed." : "שדה שם ריק אינו מותר.",
    "Hidden" : "מוסתר",
    "Visible" : "גלוי",
    "Automatic" : "אוטומטי",
    "Sunday" : "יום ראשון",
    "Monday" : "יום שני",
    "Tuesday" : "יום שלישי",
    "Wednesday" : "יום רביעי",
    "Thursday" : "יום חמישי",
    "Friday" : "יום שישי",
    "Saturday" : "שבת",
    "Add an important item in \"%s\"..." : "הוספת פריט חשוב ב־\"%s\"...",
    "Add an item due today in \"%s\"..." : "הוספת פריט שנועד להתקיים היום בשעה \"%s\"...",
    "Add an item in \"%s\"..." : "הוספת פריט ב־\"%s\"...",
    "Add a current item in \"%s\"..." : "הוספת פריט נוכחי ב־\"%s\"...",
    "Add a subtask to \"%s\"..." : "הוספת תת־פעילות ל־\"%s\"...",
    "_%n Completed Task_::_%n Completed Tasks_" : ["%n פעילות מושלמת","%n פעילויות הושלמו","%n פעילויות הושלמו","%n פעילויות הושלמו"],
    "Hours" : "שעות",
    "Minutes" : "דקות",
    "Set due date" : "הגדרת תאריך יעד",
    "%s %% completed" : "%s %% הושלמו",
    "priority %s: " : "עדיפות %s: ",
    "high" : "גבוהה",
    "medium" : "בינונית",
    "low" : "נמוכה",
    "no priority assigned" : "לא הוקצתה עדיפות",
    "Remind me" : "תזכורת",
    "at the end" : "בסוף",
    "at the beginning" : "בהתחלה",
    "Set start date" : "קביעת תאריך התחלה",
    "{calendar} shared by {owner}" : "{calendar} משותף על ידי {owner}",
    "Unnamed" : "ללא שם",
    "Important" : "חשוב",
    "Week" : "שבוע",
    "All" : "הכול",
    "Current" : "נוכחי",
    "Completed" : "הושלם",
    "The Tasks app for Nextcloud" : "יישומון המשימות ל־Nextcloud",
    "Delete" : "מחיקה",
    "Cancel" : "ביטול",
    "Edit" : "עריכה",
    "Link" : "קישור",
    "Download" : "הורדה",
    "Save" : "שמירה",
    "Add List..." : "הוספת רשימה...",
    "New List" : "רשימה חדשה",
    "Settings" : "הגדרות",
    "Start of week" : "התחלת שבוע",
    "Visibility of Smart Collections" : "הצגה של אוספים חכמים",
    "Change sort order" : "שינוי סדר מיון",
    "Default" : "בררת מחדל",
    "Due date" : "תאריך יעד",
    "Start date" : "תאריך התחלה",
    "Priority" : "עדיפות",
    "Alphabetically" : "בסדר האלף-בית",
    "Manually" : "באופן ידני",
    "Load remaining completed tasks." : "טעינת שאר הפעילויות שהושלמו.",
    "Task is completed" : "המשימה הושלמה",
    "All day" : "כל היום",
    "(New category)" : "(קטגוריה חדשה)",
    "Select categories..." : "בחירת קטגוריות…",
    "Loading the task..." : "המשימה נטענת…",
    "Task not found!" : "לא אותרה משימה!",
    "add a subtask to" : "הוספת תת־פעילות ל־",
    "Toggle subtasks" : "הפעלה/כיבוי של תת־משימות",
    "Toggle completed subtasks" : "הפעלה/כיבוי של תת־משימות שהושלמו"
},
"nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n == 2 && n % 1 == 0) ? 1: (n % 10 == 0 && n % 1 == 0 && n > 10) ? 2 : 3;");
